﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Windows.Forms;
using System.Xml.Serialization;

namespace ChemicalC
{
    public class Recipes 
    {
        public class Chemical
        {
            [XmlAttribute("chemical_name")]
            public string chemical_name { get; set; }

            [XmlAttribute("chemical_value")]
            public string chemical_value { get; set; }
        }

        public class Recipe : IEditableObject
        {

                [XmlAttribute("recipe_name")]
                public string recipe_name { get; set; }

                [XmlAttribute("size_units")]
                public string size_units { get; set; }

                [XmlAttribute("value_units")]
                public string value_units { get; set; }

                [XmlAttribute("base_area")]
                public string base_area { get; set; }


            [XmlElement("description")]
            public string description { get; set; }

            [XmlElement("chemicals")]
            public BindingList<Chemical> chemicals { get; set; }

            private string bac_recipe_name;
            private string bac_size_units;
            private string bac_value_units;
            private string bac_base_area;

            private bool inTxn = false;

            void IEditableObject.BeginEdit()
            {
                if (!inTxn)
                {
                    bac_recipe_name = recipe_name;
                    bac_size_units  = size_units;
                    bac_value_units = value_units;
                    bac_base_area   = base_area;
                }
                inTxn = true;
            }
            void IEditableObject.EndEdit()
            {
                if (inTxn) 
                inTxn = false;
            }
            void IEditableObject.CancelEdit()
            {
                if (inTxn)
                {
                    recipe_name = bac_recipe_name ;
                    size_units  = bac_size_units; 
                    value_units = bac_value_units ;
                    base_area   = bac_base_area;
                }
                inTxn = false;
            }
            public Recipe()
            {
                chemicals = new BindingList<Chemical>();
            }
        }

        [XmlElement("last_recipe", DataType ="int")]
        public int last_recipe { get; set; }

        [XmlElement("recipe")]
        public BindingList<Recipe> recipe { get; set; }

        public Recipes()
        {
            recipe = new BindingList<Recipe>();
        }
        public bool readFromXML()
        {
            try
            {
                XmlSerializer xmlSerializer = new XmlSerializer(typeof(Recipes));
                FileStream fileStream = new FileStream(Application.StartupPath + "//recipes.xml", FileMode.Open);
                this.recipe = ((Recipes)xmlSerializer.Deserialize(fileStream)).recipe;
                fileStream.Position = 0;
                this.last_recipe = ((Recipes)xmlSerializer.Deserialize(fileStream)).last_recipe;
                fileStream.Close();
                return true;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message + Environment.NewLine + "Программа попытается создать новый файл", "Error");
                return false;
            }
        }
        public void writeToXML()
        {
            try
            {
                XmlSerializer xmlSerializer = new XmlSerializer(typeof(Recipes));
                FileStream fileStream = new FileStream(Application.StartupPath + "//recipes.xml", FileMode.Create);
                xmlSerializer.Serialize(fileStream, this);
                fileStream.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Error");
            }
        }
    }
}
